@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <config.h>
@@ -342,7 +342,7 @@ void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType
 		girl->record_pid = pid;
 		girl->record_status = GIRL_RECORD_TRUE;
 
-		girl_archive_new(pid, "archive.mp3");
+		girl_archive_new("Archive", "archive.mp3");
 				
 		/* Install timeout fnction that will move the progress bar */
 		girl->timeout_id = g_timeout_add(100,(GSourceFunc)cb_timeout,girl);
